@@ -9,17 +9,18 @@ class WBool:
     why_false: str
     hook: Callable[[], Any]
 
-    def __nonzero__(self):
-        if hasattr(self.value, '__len__'):
-            return nonzero(len(self.value))  # type:ignore
-        return nonzero(self.value)
+    def __bool__(self):
+        return self.value
 
     def assert_explain(self):
         if not self:
-            self.hook()
+            try:
+                self.hook()
+            except:
+                pass
             raise AssertionError(self.why_false)
 
-    def __str__(self):
+    def __repr__(self):
         return 'True' if self else f'False: {self.why_false}'
 
 
@@ -29,7 +30,7 @@ class WBools:
     def _wbool(self, value: bool, why_false=None):
         'Boolean that describes self when failed to require'
         r = WBool()
-        r.value = value
+        r.value = bool(value)
         r.why_false = why_false
         r.hook = lambda: self.describe()
         return r
